/*
 * File : nwlayer.h
 *
 * Description : This file contains the class declaration for
 *	nwlayer.
 */

#ifndef _nwlayer_h_
#define _nwlayer_h_

#include "types.h"
#include "layer.h"
#include "inputHandler.h"

class frame;
/*
 * Class : nwlayer
 *
 * Description: The nwlayer class inherits from the layer class and
 *	the inputHandler class. It provides the basic interface to
 *	handle data-link primitives which have a direction of
 *	service-provider to service-user.
 *	The class also implements a user interface which allows us
 *	to access both the physical layer and the data-link layer.
 *	System parameters like T1 (timeout value) and N (max. number
 *	of retransmissions) can be modified. 
 *
 * Attributes:
 *	_acceptConnReq: When set to TRUE, the network layer accepts
 *	connection establishment requests, and connection reset 
 *	requests. If FALSE, the requests are denied. This variable
 *	can be set from the User interface.
 */

class nwlayer : public inputHandler , public layer {

 public:

	nwlayer(int aFd);
	~nwlayer();
	virtual void EventCallback();

	virtual void Command(int cmd, int &errorCode);
	virtual void Command(int cmd, int &errorCode, int reason); 
	virtual void Command(int cmd, int &errorCode, dataPacket *data); 

 private:
	void Parse(char *);
	void PrintCommands();
	void Trace(Boolean);
	void PhysicalLayerCommands();
	void DataLinkLayerCommands();
	void NetworkLayerCommands();
	void SetSystemParams();
	void SetFrameType(frame *fr);
	dataPacket *GetInfoField();
	void MessUpFlags(frame *fr);
	void MessUpFCS(frame *fr);
	void LessThan32Bits(frame *fr);
	void ChangeAddress(frame *fr);

	Boolean IsCmdRes();
	int 	GetPfBit();
	int		GetNr();
	int		GetNs();
	Boolean	_acceptConnReq;
};

#endif

